#ifndef NT2_INCLUDE_FUNCTIONS_ACOTD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACOTD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/acotd.hpp>

#endif
